@@ -1,4 +1,5 @@
 from hiddifypanel.models import BoolConfig,StrConfig,ConfigEnum,hconfig,ConfigCategory
+from wtforms.validators import Regexp, ValidationError
 from flask_babelex import lazy_gettext as _
 # from flask_babelex import gettext as _
 import wtforms as wtf
@@ -12,11 +13,11 @@ from flask_admin.base import expose
 import re
 from flask import render_template,current_app, Markup,url_for
 from hiddifypanel.panel.hiddify import flash
-from hiddifypanel.models import  User,Domain,DomainType,StrConfig,ConfigEnum,get_hconfigs
+from hiddifypanel.models import  *
 from hiddifypanel.panel.database import db
 from wtforms.fields import *
 from flask_classful import FlaskView
-from hiddifypanel.panel import hiddify
+from hiddifypanel.panel import hiddify,hiddify_api,custom_widgets
 class SettingAdmin(FlaskView):
     
 
@@ -51,9 +52,21 @@ class SettingAdmin(FlaskView):
                             else:
                                 if "_domain" in k or k in [ConfigEnum.admin_secret]:
                                     v=v.lower()
+                                if k == ConfigEnum.parent_panel and v!='':
+                                    # v=(v+"/").replace("/admin",'')
+                                    v=re.sub("/admin/.*","",v)
+
+                                    try:
+                                        if hiddify_api.sync_child_to_parent(v)['status']!=200:
+                                            flash(_("Can not connect to parent panel!"),'error')
+                                            return render_template('config.html', form=form)
+                                    except:
+                                        flash(_("Can not connect to parent panel!"),'error')
+                                        return render_template('config.html', form=form)
                                 StrConfig.query.filter(StrConfig.key==k).first().value=v
-                    
+
                 # print(cat,vs)
+
             db.session.commit()
             from flask_babel import refresh; refresh()
             
@@ -112,11 +125,11 @@ def get_config_form():
     # categories=sorted([ c for c in {c.key.category():1 for c in configs}])
     # dict_configs={cat:[c for c in configs if c.category==cat] for cat in categories}
     class DynamicForm(FlaskForm):pass
-
+    is_parent=hconfig(ConfigEnum.is_parent)
     for cat in ConfigCategory:
         if cat=='hidden':continue
 
-        cat_configs=[c for c in configs if c.key.category()==cat]
+        cat_configs=[c for c in configs if c.key.category()==cat and (not is_parent or c.key.show_in_parent())]
         if len(cat_configs)==0:continue
         
         class CategoryForm(FlaskForm):
@@ -134,14 +147,14 @@ def get_config_form():
             elif c.key==ConfigEnum.branding_freetext:
                 validators=[wtf.validators.Length(max=2048)]
                 render_kw={'class':"ltr",'maxlength':2048}
-                field= wtf.fields.TextAreaField(_(f'config.{c.key}.label'), validators, default=c.value, description=_(f'config.{c.key}.description'),render_kw=render_kw) 
+                field= custom_widgets.CKTextAreaField(_(f'config.{c.key}.label'), validators, default=c.value, description=_(f'config.{c.key}.description'),render_kw=render_kw) 
             else:
                 render_kw={'class':"ltr"}
                 validators=[]
                 if c.key==ConfigEnum.domain_fronting_domain:
                     validators.append(wtf.validators.Regexp("^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})|$",re.IGNORECASE,_("config.Invalid domain")))
                     validators.append(hiddify.validate_domain_exist)
-                elif 'domain' in c.key:
+                elif '_domain' in c.key:
                     validators.append(wtf.validators.Regexp("^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})$",re.IGNORECASE,_("config.Invalid domain")))
                     validators.append(hiddify.validate_domain_exist)
 
@@ -150,8 +163,10 @@ def get_config_form():
                         validators.append(wtf.validators.NoneOf([cc.value.lower() for cc in StrConfig.query.all() if cc.key!=c.key and  "fakedomain" in cc.key and cc.key!=ConfigEnum.decoy_domain],_("config.Domain already used")))
                     render_kw['required']=""
                 
+                if c.key ==ConfigEnum.parent_panel:
+                    validators.append(wtf.validators.Regexp("()|(http(s|)://([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})/.*)",re.IGNORECASE,_("Invalid admin link")))
 
-                if c.key==ConfigEnum.branding_site:
+                if c.key==ConfigEnum.branding_site :
                     validators.append(wtf.validators.Regexp("()|(http(s|)://([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})/?.*)",re.IGNORECASE,_("config.Invalid brand link")))
                     # render_kw['required']=""
 
