@@ -2,18 +2,14 @@ from flask import abort, jsonify,request
 from flask_restful import Resource
 # from flask_simplelogin import login_required
 import datetime
-from hiddifypanel.models import StrConfig,BoolConfig,User,Domain,get_hconfigs,Proxy
+from hiddifypanel.models import *
 from urllib.parse import urlparse
-from hiddifypanel.panel import hiddify
+from hiddifypanel.panel import hiddify,hiddify_api
 class AllResource(Resource):
     def get(self):
         products = User.query.all() or abort(204)
         response= jsonify(
-            {"users": [u.to_dict() for u in User.query.filter((User.usage_limit_GB>User.current_usage_GB)).filter(User.expiry_time>=datetime.date.today()).all()],
-            "domains": [hiddify.domain_dict(u) for u in Domain.query.all()],
-            "proxies": [u.to_dict() for u in Proxy.query.all()],
-            "hconfigs": get_hconfigs()
-            }
+            hiddify.dump_db_to_dict()            
         )
         o = urlparse(request.base_url)
         domain=o.hostname
@@ -22,6 +18,7 @@ class AllResource(Resource):
         return response
 
 
+
 class UserResource(Resource):
     def get(self):
         products = User.query.all() or abort(204)
@@ -52,4 +49,6 @@ class StrConfigResource(Resource):
 
 class HelloResource(Resource):
     def get(self):
-        return jsonify({"ok": True})
+        return jsonify({"status": 200,"msg":"ok"})
+
+
